OC.L10N.register(
    "files",
    {
    "File could not be found" : "Berkas tidak ditemukan",
    "Move or copy" : "Pindah atau salin",
    "Download" : "Unduh",
    "Delete" : "Hapus",
    "Tags" : "Tag",
    "Show list view" : "Tampilkan sebagai daftar",
    "Show grid view" : "Tampilkan sebagai kisi",
    "Home" : "Beranda",
    "Close" : "Tutup",
    "Could not create folder \"{dir}\"" : "Tidak dapat membuat folder \"{dir}\"",
    "This will stop your current uploads." : "Ini akan menghentikan proses pengunggahan.",
    "Upload cancelled." : "Pengunggahan dibatalkan.",
    "Processing files …" : "Memproses berkas ...",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Tidak dapat mengunggah {filename} karena ini sebuah direktori atau memiliki ukuran 0 bita",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ruang bebas tidak mencukupi, Anda mengunggah {size1} tetapi hanya {size2} yang tersisa",
    "Target folder \"{dir}\" does not exist any more" : "Folder target \"{dir}\" sudah tidak ada lagi",
    "Not enough free space" : "Ruang kosong tidak cukup",
    "An unknown error has occurred" : "Terjadi galat yang tak diketahui",
    "File could not be uploaded" : "Berkas tidak dapat diunggah",
    "Uploading …" : "Mengunggah …",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} dari {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Pengunggahan itu tidak didukung",
    "Target folder does not exist any more" : "Folder target sudah tidak ada lagi",
    "Operation is blocked by access control" : "Tindakan diblokir oleh kontrol akses",
    "Error when assembling chunks, status code {status}" : "Galat saat merakit potongan, kode status {status}",
    "Actions" : "Tindakan",
    "Rename" : "Ubah nama",
    "Move" : "Pindah",
    "Copy" : "Salin",
    "Choose target folder" : "Pilih folder target",
    "Edit locally" : "Sunting secara lokal",
    "Open" : "Buka",
    "Could not load info for file \"{file}\"" : "Tidak dapat menampilkan info berkas \"{file}\"",
    "Files" : "Berkas",
    "Details" : "Rincian",
    "Please select tag(s) to add to the selection" : "Silakan pilih tag untuk ditambahkan ke pilihan",
    "Apply tag(s) to selection" : "Tetapkan tag ke pilihan",
    "Select directory \"{dirName}\"" : "Pilih direktori \"{dirName}\"",
    "Select file \"{fileName}\"" : "Pilih berkas \"{fileName}\"",
    "Pending" : "Tertunda",
    "Unable to determine date" : "Tidak dapat menentukan tanggal",
    "This operation is forbidden" : "Operasi ini dilarang",
    "This directory is unavailable, please check the logs or contact the administrator" : "Direktori ini tidak tersedia, silakan periksa log atau hubungi kontak",
    "Storage is temporarily not available" : "Penyimpanan sementara tidak tersedia",
    "Could not move \"{file}\", target exists" : "Tidak dapat memindahkan \"{file}\", sudah ada",
    "Could not move \"{file}\"" : "Tidak dapat memindahkan \"{file}\"",
    "copy" : "salin",
    "Could not copy \"{file}\", target exists" : "Tidak dapat menyalin \"{file}\", target eksis",
    "Could not copy \"{file}\"" : "Tidak dapat menyalin \"{file}\"",
    "Copied {origin} inside {destination}" : "{origin} tersalin ke {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} dan {nbfiles} berkas lainnya tersalin ke {destination}",
    "Failed to redirect to client" : "Gagal mengarahkan ke klien",
    "{newName} already exists" : "{newName} sudah ada",
    "Could not rename \"{fileName}\", it does not exist any more" : "Tidak dapat mengganti \"{fileName}\", tidak ada lagi",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Nama \"{targetName}\" sudah digunakan di folder \"{dir}\". Gunakan nama yang lain.",
    "Could not rename \"{fileName}\"" : "Tidak dapat mengganti \"{fileName}\"",
    "Could not create file \"{file}\"" : "Tidak dapat membuat berkas \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Tidak dapat membuat berkas \"{file}\" karena sudah ada",
    "Could not create folder \"{dir}\" because it already exists" : "Tidak dapat membuat folder \"{dir}\" karena sudah ada",
    "Could not fetch file details \"{file}\"" : "Tidak dapat memperoleh detail berkas \"{file}\"",
    "Error deleting file \"{fileName}\"." : "Terjadi kesalahan saat menghapus berkas \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Hasil pencarian tidak ditemukan di folder lainnya untuk '{tag}{filter}{endtag}'",
    "Enter more than two characters to search in other folders" : "Masukkan lebih dari dua karakter untuk mencari di folder lain",
    "Name" : "Nama",
    "Size" : "Ukuran",
    "Modified" : "Dimodifikasi",
    "_%n folder_::_%n folders_" : ["%n folder"],
    "_%n file_::_%n files_" : ["%n berkas"],
    "{dirs} and {files}" : "{dirs} dan {files}",
    "_including %n hidden_::_including %n hidden_" : ["Termasuk %n tersembunyi"],
    "You do not have permission to upload or create files here" : "Anda tidak memiliki izin untuk mengunggah atau membuat berkas di sini",
    "_Uploading %n file_::_Uploading %n files_" : ["Mengunggah %n berkas"],
    "New" : "Baru",
    "New file/folder menu" : "Menu berkas/folder baru",
    "Select file range" : "Pilih rentang berkas",
    "{used}%" : "{used}%",
    "{used} of {quota} used" : "{used} dari {quota} terpakai",
    "{used} used" : "{used} terpakai",
    "\"{name}\" is an invalid file name." : "\"{name}\" adalah nama berkas yang tidak sah.",
    "File name cannot be empty." : "Nama berkas tidak boleh kosong.",
    "\"/\" is not allowed inside a file name." : "\"/\" tidak diizinkan pada nama berkas.",
    "\"{name}\" is not an allowed filetype" : "Tipe berkas \"{name}\" tidak diizinkan",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Penyimpanan {owner} penuh, berkas tidak dapat diperbarui atau disinkronisasikan lagi!",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Folder grup \"{mountPoint}\" penuh, berkas tidak dapat diperbarui atau disinkronisasikan lagi!",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Penyimpanan eksternal \"{mountPoint}\" penuh, berkas tidak dapat diperbarui atau disinkronisasi lagi!",
    "Your storage is full, files cannot be updated or synced anymore!" : "Penyimpanan Anda penuh, berkas tidak dapat diperbarui atau disinkronisasikan lagi!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Penyimpanan {owner} hampir penuh ({usedSpacePercent}%).",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Folder grup \"{mountPoint}\" hampir penuh ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Penyimpanan eksternal \"{mountPoint}\" hampir penuh ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Penyimpanan Anda hampir penuh ({usedSpacePercent}%).",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["cocok dengan \"{filter}\""],
    "View in folder" : "Lihat dalam folder",
    "Path" : "Jalur",
    "_%n byte_::_%n bytes_" : ["%n byte"],
    "Favorited" : "Difavoritkan",
    "Favorite" : "Favorit",
    "New folder" : "Folder baru",
    "Create new folder" : "Buat direktori baru",
    "Upload file" : "Unggah berkas",
    "Recent" : "Terbaru",
    "Not favorited" : "Tidak favorit",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Tambah ke favorit",
    "An error occurred while trying to update the tags" : "Terjadi kesalahan saat mencoba untuk memperbarui label",
    "Added to favorites" : "Tambah ke favorit",
    "Removed from favorites" : "Terbuang dari favorit",
    "You added {file} to your favorites" : "Anda menambahkan {file} ke favorit",
    "You removed {file} from your favorites" : "Anda membuang {file} dari favorit",
    "Favorites" : "Favorit",
    "File changes" : "Berkas berubah",
    "Created by {user}" : "Dibuat oleh {user}",
    "Changed by {user}" : "Diubah oleh {user}",
    "Deleted by {user}" : "Dihapus oleh {user}",
    "Restored by {user}" : "Dipulihkan oleh {user}",
    "Renamed by {user}" : "Diganti nama oleh {user}",
    "Moved by {user}" : "Dipindahkan oleh {user}",
    "You created {file}" : "Anda membuat {file}",
    "You created an encrypted file in {file}" : "Anda membuat berkas terenkripsi pada {file}",
    "{user} created {file}" : "{user} membuat {file}",
    "{user} created an encrypted file in {file}" : "{user} membuat berkas terenkripsi pada {file}",
    "{file} was created in a public folder" : "{file} dibuat pada folder publik",
    "You changed {file}" : "Anda mengubah {file}",
    "You changed an encrypted file in {file}" : "Anda mengubah berkas terenkripsi pada {file}",
    "{user} changed {file}" : "{user} mengubah {file}",
    "{user} changed an encrypted file in {file}" : "{user} mengubah berkas terenkripsi pada {file}",
    "You deleted {file}" : "Anda menghapus {file}",
    "You deleted an encrypted file in {file}" : "Anda menghapus berkas terenkripsi pada {file}",
    "{user} deleted {file}" : "{user} menghapus {file}",
    "{user} deleted an encrypted file in {file}" : "{user} menghapus berkas terenkripsi pada {file}",
    "You restored {file}" : "Anda memulihkan {file}",
    "{user} restored {file}" : "{user} memulihkan {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Anda mengubah nama {oldfile} (tersembunyi) ke {newfile} (tersembunyi)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Anda mengubah nama {oldfile} (tersembunyi) ke {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Anda mengubah nama {oldfile} ke {newfile} (tersembunyi)",
    "You renamed {oldfile} to {newfile}" : "Anda mengganti nama {oldfile} menjadi {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} mengubah nama {oldfile} (tersembunyi) ke {newfile} (tersembunyi)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} mengubah nama {oldfile} (tersembunyi) ke {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} mengubah nama {oldfile} ke {newfile} (tersebunyi)",
    "{user} renamed {oldfile} to {newfile}" : "{user} mengganti nama {oldfile} menjadi {newfile}",
    "You moved {oldfile} to {newfile}" : "Anda memindahkan {oldfile} menjadi {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} memindahkan {oldfile} menjadi {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Suatu berkas telah ditambahkan atau dibuang dari <strong>favorit</strong>",
    "A file or folder has been <strong>changed</strong>" : "Sebuah berkas atau folder telah <strong>diubah</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Sebuah berkas atau folder favorit telah <strong>diubah</strong>",
    "Upload (max. %s)" : "Unggah (maks. %s)",
    "Accept" : "Terima",
    "Reject" : "Ditolak",
    "Incoming ownership transfer from {user}" : "Permintaan transfer kepemilikan dari {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Apakah Anda ingin menerima {path}?\n\nCatatan: Setelah diterima, proses transfer butuh kurang lebih 1 jam.",
    "Ownership transfer failed" : "Transfer kepemilikan gagal",
    "Your ownership transfer of {path} to {user} failed." : "Transfer kepemilikan Anda pada {path} ke {user} gagal.",
    "The ownership transfer of {path} from {user} failed." : "Transfer kepemilikan pada {path} dari {user} gagal.",
    "Ownership transfer done" : "Transfer kepemilikan selesai",
    "Your ownership transfer of {path} to {user} has completed." : "Transfer kepemilikan Anda pada {path} ke {user} selesai.",
    "The ownership transfer of {path} from {user} has completed." : "Transfer kepemilikan pada {path} dari {user} selesai.",
    "in %s" : "dalam %s",
    "File Management" : "Pengelolaan Berkas",
    "You don’t have permission to upload or create files here" : "Anda tidak memiliki akses untuk mengunggah atau membuat berkas di sini",
    "Folder name" : "Nama folder",
    "File not found" : "Berkas tidak ditemukan",
    "Storage informations" : "Informasi penyimpanan",
    "{usedQuotaByte} used" : "{usedQuotaByte} digunakan",
    "{relative}% used" : "{relative}% digunakan",
    "Could not refresh storage stats" : "Tidak dapat memuat ulang statistik penyimpanan",
    "Your storage is full, files can not be updated or synced anymore!" : "Ruang penyimpanan Anda penuh, berkas tidak dapat diperbarui atau disinkronkan lagi!",
    "Create" : "Buat",
    "Transfer ownership of a file or folder" : "Transfer kepemilikan dari berkas atau folder",
    "Choose file or folder to transfer" : "Pilih berkas atau folder untuk transfer",
    "Change" : "Ubah",
    "New owner" : "Pemilik baru",
    "Choose a file or folder to transfer" : "Pilih berkas atau folder untuk ditransfer",
    "Transfer" : "Transfer",
    "Transfer {path} to {userid}" : "Transfer {path} ke {user}",
    "Invalid path selected" : "Jalur terpilih invalid",
    "Unknown error" : "Kesalahan tidak diketahui",
    "Ownership transfer request sent" : "Permintaan transfer kepemilikan terkirim",
    "Cannot transfer ownership of a file or folder you do not own" : "Tidak dapat mentransfer pemilik berkas atau folder yang Anda tidak miliki",
    "Select file or folder to link to" : "Pilih berkas atau folder untuk ditautkan",
    "No files in here" : "Tidak ada berkas di sini",
    "Upload some content or sync with your devices!" : "Unggah beberapa konten dan sinkronisasikan dengan perangkat Anda!",
    "Go back" : "Kembali",
    "Shared by link" : "Dibagikan dengan tautan",
    "Shared" : "Dibagikan",
    "Open the files app settings" : "Buka setelan aplikasi berkas",
    "Files settings" : "Setelan berkas",
    "File cannot be accessed" : "Berkas tidak dapat diakses",
    "Show hidden files" : "Lihat berkas tersembunyi",
    "Crop image previews" : "Pangkas pratinjau gambar",
    "Additional settings" : "Setelan tambahan",
    "WebDAV" : "WebDAV",
    "Copy to clipboard" : "Salin ke papan klip",
    "Use this address to access your Files via WebDAV" : "Gunakan alamat ini untuk mengakses Berkas Anda via WebDAV",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Jika Anda telah mengaktifkan 2FA, Anda harus membuat dan menggunakan sebuah kata sandi aplikasi baru dengan mengeklik di sini.",
    "Clipboard is not available" : "Papan klip tidak tersedia",
    "WebDAV URL copied to clipboard" : "URL WebDAV disalin ke papan klip",
    "Unable to change the favourite state of the file" : "Gagal mengubah status favorit berkas",
    "Error while loading the file data" : "Galat pemuatan data berkas",
    "Pick a template for {name}" : "Pilih templat untuk {name}",
    "Create a new file with the selected template" : "Buat sebuah berkas baru dengan templat yang dipilih",
    "Creating file" : "Membuat berkas",
    "Blank" : "Kosong",
    "Unable to create new file from template" : "Tidak dapat membuat berkas baru dari templat",
    "Delete permanently" : "Hapus secara permanen",
    "Cancel" : "Membatalkan",
    "Filename" : "Nama berkas",
    "Unable to initialize the templates directory" : "Tidak dapat membuat direktori templat",
    "Templates" : "Templat",
    "No favorites yet" : "Belum memiliki favorit",
    "Files and folders you mark as favorite will show up here" : "Berkas dan folder yang Anda tandai sebagai favorit akan ditampilkan di sini.",
    "All files" : "Semua berkas",
    "No entries found in this folder" : "Tidak ada entri yang ditemukan dalam folder ini",
    "Select all" : "Pilih Semua",
    "Upload too large" : "Yang diunggah terlalu besar",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Berkas yang dicoba untuk diunggah melebihi ukuran maksimum pengunggahan berkas di server ini.",
    "Text file" : "Berkas teks",
    "New text file.txt" : "Teks baru file.txt",
    "Direct link was copied (only works for users who have access to this file/folder)" : "Tautan langsung disalin (hanya bisa untuk pengguna yang memiliki akses ke berkas/folder ini)",
    "Copy direct link (only works for users who have access to this file/folder)" : "Salin tautan langsung (hanya berlaku bagi pengguna yang telah memiliki akses ke berkas/folder ini)",
    "You can only favorite a single file or folder at a time" : "Anda hanya dapat memfavoritkan satu berkas atau folder dalam satu waktu",
    "\"remote user\"" : "\"remote user\"",
    "Search users" : "Cari pengguna",
    "You might not have have permissions to view it, ask the sender to share it" : "Anda mungkin tidak memiliki izin untuk menampilkan ini, tanyakan pengirim untuk membagikannya",
    "Set up templates folder" : "Siapkan folder templat",
    "Toggle %1$s sublist" : "Alih %1$s subdaftar",
    "Toggle grid view" : "Alihkan tampilan jala-jala",
    "Deleted files" : "Berkas terhapus",
    "Shares" : "Dibagikan",
    "Shared with others" : "Dibagikan dengan lainnya",
    "Shared with you" : "Shared with you",
    "Deleted shares" : "Berbagi terhapus",
    "Pending shares" : "Berbagi tertunda",
    "Unselect all" : "Batalkan semua pemilihan",
    "Choose" : "Pilih",
    "Add" : "Tambah"
},
"nplurals=1; plural=0;");
